# coding=utf-8
# Copyright 2021 The TensorFlow Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""quac dataset."""

import tensorflow_datasets.public_api as tfds
from tensorflow_datasets.text.quac import quac


class QuacTest(tfds.testing.DatasetBuilderTestCase):
  """Tests for quac dataset."""
  DATASET_CLASS = quac.Quac
  DL_EXTRACT_RESULT = {
      "train": "train_v0.2.json",
      "val": "val_v0.2.json",
  }
  SPLITS = {
      "train": 8,  # Number of fake train example
      "validation": 8,  # Number of fake validation example
  }


if __name__ == "__main__":
  tfds.testing.test_main()
